@@ -3,7 +3,9 @@ package Test::Siebel::Srvrmgr::Daemon::Action;
 use Test::Most;
 use Siebel::Srvrmgr::ListParser;
 use Test::Moose 'has_attribute_ok';
-use Cwd;
+use Test::TempDir::Tiny;
+use File::Spec;
+use Config;
 use parent qw(Test::Siebel::Srvrmgr);
 
 sub get_parser {
@@ -54,11 +56,20 @@ sub get_col_sep {
 
 }
 
+sub get_temp_dir {
+
+    my $test = shift;
+    return $test->{temp_dir};
+
+}
+
 sub before : Tests(setup) {
 
     my $test       = shift;
     my $params_ref = shift;
 
+    $test->{temp_dir} = tempdir();
+
     if (    ( $test->get_struct() eq 'delimited' )
         and ( defined( $test->get_col_sep() ) ) )
     {
@@ -94,7 +105,8 @@ sub before : Tests(setup) {
             $test->class()->new(
                 {
                     parser => $test->get_parser(),
-                    params => ['foobar']
+                    params =>
+                      [ File::Spec->catfile( $test->{temp_dir}, 'foobar' ) ]
                 }
             )
         );
@@ -173,7 +185,7 @@ sub clean_up : Test(shutdown) {
     my $test = shift;
 
     # removes the dump files
-    my $dir = getcwd();
+    my $dir = $test->get_temp_dir();
 
     opendir( DIR, $dir ) or die "Cannot read $dir: $!\n";
     my @files = readdir(DIR);
@@ -181,18 +193,30 @@ sub clean_up : Test(shutdown) {
 
 # :TODO      :08/07/2013 12:50:22:: change for a proper interface instead hoping for data structure be the expected
     my $filename = '^' . ( @{ $test->get_action()->get_params() } )[0];
+	
+	# to avoid warnings with matching regular expression due the backslash used
+	# by Windows
+	if ( $Config{osname} eq 'MSWin32' ) {
+	
+		$filename =~ s/\\/\\\\/g;
+	
+	}
+	
     my $regex = qr/$filename/;
 
     foreach my $file (@files) {
 
         if ( $file =~ /$regex/ ) {
 
-            unlink $file or warn "Cannot remove $file: $!\n";
+            my $path = File::Spec->catfile( $dir, $file );
+            unlink $path or diag("Cannot remove $path: $!");
 
         }
 
     }
 
+    rmdir($dir) or diag("Cannot remove $dir: $!");
+
 }
 
 1;
